import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns

# Définition de la palette de couleurs
color_palette = {
    'gpt-4.5-preview-2025-02-27': '#7abaff',  # bleuEvasion
    'llama3': '#32a68c',  # vertAvenir
    'llama3.3:latest': '#4b9f7d',  # vertLlama3.3
    'mistral-small': '#ff6941',  # orangeChaleureux
    'mixtral:8x7b': '#f1a61a',  # jauneMixtral (nouvelle couleur)
    'deepseek-r1': '#5862ed',  # indigoInclusif
    'deepseek-r1:7b': '#9a7bff'  # violetDeepseek-r1:7b (nouvelle couleur)
}

# Charger les données
data = pd.read_csv("../../data/dictator/dictator.csv")  # Remplacez par le bon chemin vers votre fichier CSV

# Spécifier l'ordre des modèles pour l'axe x
model_order = [
    'gpt-4.5-preview-2025-02-27',
    'llama3', 'llama3.3:latest',  # Mettre côte à côte
    'mistral-small', 'mixtral:8x7b',  # Rapprocher
    'deepseek-r1', 'deepseek-r1:7b'
]

# Création du boxplot
plt.figure(figsize=(12, 6))
sns.boxplot(
    data=data,
    x="model",
    y="my_share",
    hue="model",  # Explicitly assign hue
    palette=color_palette,
    showfliers=False,
    legend=False,  # Disable legend since hue is just for color mapping
    order=model_order  # Réorganiser l'ordre des modèles sur l'axe x
)

# Ajouter médiane, premier et troisième quartile
for i, model in enumerate(model_order):
    subset = data[data["model"] == model]["my_share"]
    median = subset.median()
    q1 = subset.quantile(0.25)
    q3 = subset.quantile(0.75)
    plt.text(i, median, f"{median:.0f}", ha='center', va='bottom', fontsize=10, fontweight='bold', color='black')
    plt.text(i, q1, f"{q1:.0f}", ha='center', va='top', fontsize=9, color='black')
    plt.text(i, q3, f"{q3:.0f}", ha='center', va='bottom', fontsize=9, color='black')

# Labels et titre
plt.xlabel("Model")
plt.ylabel("Share of money allocated to oneself")
plt.title("Distribution of self-allocated share per model in the dictator game")

# Sauvegarde et affichage
plt.savefig("../../figures/dictator/dictator_boxplot.svg", format="svg")