import pandas as pd
import seaborn as sns
import matplotlib.pyplot as plt

# Custom color palette
color_palette = {
    'random': '#333333',  # Black
    'gpt-4.5-preview-2025-02-27': '#7abaff',  # BlueEscape
    'llama3': '#32a68c',  # GreenFuture
    'llama3.3:latest': '#4b9f7d',  # GreenLlama3.3
    'mistral-small': '#ff6941',  # WarmOrange
    'mixtral:8x7b': '#f1a61a',  # YellowMixtral
    'deepseek-r1': '#5862ed',  # InclusiveIndigo
    'deepseek-r1:7b': '#9a7bff'  # PurpleDeepseek-r1:7b
}

# Specify the order of models for the x-axis
model_order = [
    'random',
    'gpt-4.5-preview-2025-02-27',
    'llama3', 'llama3.3:latest',  # Place llama3 and llama3.3:latest together
    'mistral-small', 'mixtral:8x7b',  # Bring mistral-small and mixtral:8x7b closer
    'deepseek-r1', 'deepseek-r1:7b'
]


# Load CSV file
file_path = "../../data/investment/investment.csv"  # Update path
df = pd.read_csv(file_path)

# Clean column names
df.columns = df.columns.str.strip()

# Ensure required columns exist
if "ccei" not in df.columns or "model" not in df.columns:
    raise ValueError("Missing required columns ('ccei' or 'model') in the dataset!")

# Set Seaborn style
sns.set(style="whitegrid")

# Create figure
plt.figure(figsize=(10, 6))

# Draw violin plot (replacing boxplot with violinplot)
sns.violinplot(data=df, x="model", y="ccei", palette=color_palette, order=model_order)

# Add plot labels
plt.title("CCEI Distribution by Model", fontsize=14)
plt.xlabel("Model", fontsize=12)
plt.ylabel("CCEI Value", fontsize=12)

# Rotate x-axis labels for better readability
plt.xticks(rotation=20)

# Save the figure
output_path = "../../figures/investment/investment_violin.svg"
plt.savefig(output_path, format="svg")
