import asyncio
import csv
from investment import Investment

# Define models, temperature, and iterations
models = ["deepseek-r1:7b"]  # "gpt-4.5-preview-2025-02-27", "optimal", "random", "llama3", "mistral-small", "deepseek-r1", "mixtral:8x7b", "llama3.3:latest",
temperature = 0.0
iterations = 30
output_file = "../../data/investment/investment.csv"

async def run_experiment():
    # Open CSV file to store results
    with open(output_file, mode="w", newline="") as file:
        writer = csv.writer(file)
        writer.writerow(["iteration", "model", "temperature", "ccei"])  # CSV header

        # Run each model for multiple iterations
        for model in models:
            print(f"Running experiments for model: {model}")
            for iteration in range(1, iterations + 1):
                print(f"Iteration {iteration}/{iterations} for {model}")

                # Run DictatorConsistency experiment
                game_agent = Investment(model=model, temperature=temperature)
                ccei_value = await game_agent.run_rounds(25)  # Run 25 rounds

                # Write results to CSV
                writer.writerow([iteration, model, temperature, ccei_value])
                file.flush()  # Ensure data is written immediately
                print(f"Saved iteration {iteration} for {model} -> CCEI: {ccei_value}")

# Run the async function
if __name__ == "__main__":
    asyncio.run(run_experiment())